@@ -5,11 +5,10 @@
  *
  * The library is free for all purposes without any express
  * guarantee it works.
- *
- * Tom St Denis, tomstdenis@gmail.com, http://libtomcrypt.com
  */
 #include "tomcrypt.h"
 
+#ifndef LTC_NO_FILE
 /** 
   @file hash_file.c
   Hash a file, Tom St Denis
@@ -24,10 +23,6 @@
 */
 int hash_file(int hash, const char *fname, unsigned char *out, unsigned long *outlen)
 {
-#ifdef LTC_NO_FILE
-    (void)hash; (void)fname; (void)out; (void)outlen;
-    return CRYPT_NOP;
-#else
     FILE *in;
     int err;
     LTC_ARGCHK(fname  != NULL);
@@ -49,10 +44,10 @@ int hash_file(int hash, const char *fname, unsigned char *out, unsigned long *ou
     }
 
     return err;
-#endif
 }
+#endif /* #ifndef LTC_NO_FILE */
 
 
-/* $Source: /cvs/libtom/libtomcrypt/src/hashes/helper/hash_file.c,v $ */
-/* $Revision: 1.4 $ */
-/* $Date: 2006/03/31 14:15:35 $ */
+/* ref:         $Format:%D$ */
+/* git commit:  $Format:%H$ */
+/* commit time: $Format:%ai$ */
