@@ -1,3 +1,5 @@
+#include <tommath_private.h>
+#ifdef BN_MP_ADD_C
 /* LibTomMath, multiple-precision integer library -- Tom St Denis
  *
  * LibTomMath is a library that provides multiple-precision
@@ -10,13 +12,11 @@
  * The library is free for all purposes without any express
  * guarantee it works.
  *
- * Tom St Denis, tomstdenis@iahu.ca, http://math.libtomcrypt.org
+ * Tom St Denis, tstdenis82@gmail.com, http://libtom.org
  */
-#include <tommath.h>
 
 /* high level addition (handles signs) */
-int
-mp_add (mp_int * a, mp_int * b, mp_int * c)
+int mp_add (mp_int * a, mp_int * b, mp_int * c)
 {
   int     sa, sb, res;
 
@@ -46,3 +46,8 @@ mp_add (mp_int * a, mp_int * b, mp_int * c)
   return res;
 }
 
+#endif
+
+/* ref:         $Format:%D$ */
+/* git commit:  $Format:%H$ */
+/* commit time: $Format:%ai$ */
