@@ -1,3 +1,5 @@
+#include <tommath_private.h>
+#ifdef BN_MP_INIT_SIZE_C
 /* LibTomMath, multiple-precision integer library -- Tom St Denis
  *
  * LibTomMath is a library that provides multiple-precision
@@ -10,24 +12,37 @@
  * The library is free for all purposes without any express
  * guarantee it works.
  *
- * Tom St Denis, tomstdenis@iahu.ca, http://math.libtomcrypt.org
+ * Tom St Denis, tstdenis82@gmail.com, http://libtom.org
  */
-#include <tommath.h>
 
 /* init an mp_init for a given size */
 int mp_init_size (mp_int * a, int size)
 {
+  int x;
+
   /* pad size so there are always extra digits */
   size += (MP_PREC * 2) - (size % MP_PREC);	
   
   /* alloc mem */
-  a->dp = OPT_CAST XCALLOC (sizeof (mp_digit), size);
+  a->dp = OPT_CAST(mp_digit) XMALLOC (sizeof (mp_digit) * size);
   if (a->dp == NULL) {
     return MP_MEM;
   }
+
+  /* set the members */
   a->used  = 0;
   a->alloc = size;
   a->sign  = MP_ZPOS;
 
+  /* zero the digits */
+  for (x = 0; x < size; x++) {
+      a->dp[x] = 0;
+  }
+
   return MP_OKAY;
 }
+#endif
+
+/* ref:         $Format:%D$ */
+/* git commit:  $Format:%H$ */
+/* commit time: $Format:%ai$ */
